@@ -10,7 +10,6 @@
 #ifndef CSNIPPET_H
 #define CSNIPPET_H
 
-#include "plugin_katesnippets.h"
 #include <qobject.h>
 #include <qlistview.h>
 #include <kaction.h>
@@ -20,31 +19,21 @@
 @author Stephan Mres
 */
 
-class KatePluginKateSnippets;
-//class PluginView;
-
-class CSnippet : public QObject
-{
-Q_OBJECT
+class CSnippet : public QObject {
+  Q_OBJECT
 public:
-    CSnippet(QString sKey, QString sValue, QListViewItem *lvi, KatePluginKateSnippets *plugin, QSignalMapper *actionmapper, QObject *parent = 0, const char *name = 0);
-    CSnippet(QObject *parent = 0, const char *name = 0);
-    ~CSnippet();
-	QString getKey() 						{ return sKey; };
-	QString getValue()						{ return sValue; };
-	QListViewItem* getListViewItem() const	{ return lvi; };
-	void setKey(const QString& sKey) 				{ this->sKey = sKey; /*this->action->setText(sKey);*/ };
-	void setValue(const QString& sValue) 			{ this->sValue = sValue; };
-
-//	static int iActionNr;
+  CSnippet(QString sKey, QString sValue, QListViewItem *lvi, QObject *parent = 0, const char *name = 0);
+  ~CSnippet();
+  QString getKey() 						{ return _sKey; }
+  QString getValue()						{ return _sValue; }
+  QListViewItem* getListViewItem() const	{ return _lvi; }
+  void setKey(const QString& sKey) 				{ _sKey = sKey; }
+  void setValue(const QString& sValue) 			{ _sValue = sValue; }
 
 protected:
- 	KatePluginKateSnippets *plugin;
-//	QSignalMapper *actionmapper;
- 	QString sKey;
-	QString sValue;
-	QListViewItem *lvi;
-	KAction *action;
+  QString            _sKey;
+  QString            _sValue;
+  QListViewItem      *_lvi;
 };
 
 #endif
