@@ -188,7 +188,8 @@ PluginKateTextFilter::slotFilterReceivedStdout (KProcess * pProcess, char * got,
 
   //  TODO: got a better idea?
 
-  		while (len--)  m_strFilterOutput += *got++;
+//   		while (len--)  m_strFilterOutput += *got++;
+    m_strFilterOutput += QString::fromLocal8Bit( got, len );
 //		POP_(m_strFilterOutput);
 		}
 
