@@ -30,7 +30,7 @@
 
 #include <kprocess.h>
 
-class PluginKateTextFilter : public Kate::Plugin, Kate::PluginViewInterface
+class PluginKateTextFilter : public Kate::Plugin, public Kate::PluginViewInterface, public Kate::Command
 {
   Q_OBJECT
 
@@ -41,9 +41,16 @@ class PluginKateTextFilter : public Kate::Plugin, Kate::PluginViewInterface
     void addView (Kate::MainWindow *win);
     void removeView (Kate::MainWindow *win);
 
+    // Kate::Command
+    QStringList cmds ();
+    bool exec (Kate::View *view, const QString &cmd, QString &msg);
+    bool help (Kate::View *view, const QString &cmd, QString &msg);
+  private:
+    void runFilter( Kate::View *kv, const QString & filter );
+
   private:
     QString  m_strFilterOutput;
-    KShellProcess * m_pFilterShellProcess;       
+    KShellProcess * m_pFilterShellProcess;
     QPtrList<class PluginView> m_views;
     QStringList completionList;
   public slots:
@@ -55,3 +62,4 @@ class PluginKateTextFilter : public Kate::Plugin, Kate::PluginViewInterface
 };
 
 #endif // _PLUGIN_KANT_TEXTFILTER_H
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
