@@ -26,8 +26,9 @@
 
 #include <kpanelapplet.h>
 
+#include "simplebutton.h"
+
 class KInstance;
-class QPushButton;
 class QPopupMenu;
 
 class KolourPicker : public KPanelApplet
@@ -59,7 +60,7 @@ private:
 
 	KInstance *m_instance;
 	bool m_picking;
-	QPushButton *m_historyButton, *m_colourButton;
+	SimpleButton *m_historyButton, *m_colourButton;
 	QValueList<QColor> m_history;
 	QMap<int, QStringList> m_colorNames;
 };
