@@ -52,7 +52,7 @@
 #include <kbugreport.h>
 #include <dcopclient.h>
 
-const int MC_BUTTONSIZE = 18; // TODO: Might become dynamical for bigger panels
+const int MC_BUTTONSIZE = 20; // TODO: Might become dynamical for bigger panels
 const int NO_BUTTONS = 4;
 
 extern "C"
@@ -104,6 +104,7 @@ MediaControl::MediaControl(const QString &configFile, Type t, int actions,
 			0,
 			"http://metz.gehn.net"))
 {
+	setBackgroundOrigin(AncestorOrigin);
 	_player = 0L;
 	_prefsDialog = 0L;
 
@@ -515,6 +516,16 @@ bool MediaControl::eventFilter(QObject *, QEvent *e)
 	return false;
 }
 
+void MediaControl::paletteChange( const QPalette& )
+{
+    time_slider->setBackground();
+}
+
+void MediaControl::moveEvent( QMoveEvent* )
+{
+    time_slider->setBackground();
+}
+
 // Danger: Weird Code ahead! ;))
 void MediaControl::resizeEvent( QResizeEvent* )
 {
@@ -590,45 +601,14 @@ void MediaControl::resizeEvent( QResizeEvent* )
 // Our Button ========================================================================
 
 TrayButton::TrayButton(QWidget* parent, const char* name)
-	: QPushButton (parent, name)
+	: SimpleButton (parent, name)
 {
 	setBackgroundMode(PaletteBackground);
 	setBackgroundOrigin(AncestorOrigin);
 }
 
-void TrayButton::drawButton(QPainter *p)
+void TrayButton::setIconSet(const QIconSet &iconSet)
 {
-	QPixmap bg(size());
-	QPainter pbg;
-
-	pbg.begin(&bg);
-	if (parentWidget() && parentWidget()->backgroundPixmap())
-		pbg.drawTiledPixmap(0, 0, width(), height(), *(parentWidget()->backgroundPixmap()), x(), y());
-	else
-		pbg.fillRect(rect(), colorGroup().brush(QColorGroup::Background));
-
-
-	if (isDown() || isOn())
-	{
-		// Draw shapes to indicate the down state.
-		style().drawPrimitive(QStyle::PE_Panel, &pbg, rect(), colorGroup(),
-			QStyle::Style_Sunken);
-	}
-	pbg.end();
-
-	p->drawPixmap(0,0,bg); // draw the background
-
-	QPixmap pixmap = iconSet()->pixmap(
-		QIconSet::Automatic,
-		isEnabled() ? QIconSet::Normal : QIconSet::Disabled,
-		isOn() ? QIconSet::On : QIconSet::Off);
-
-	// draw icon
-	if(!pixmap.isNull())
-	{
-		QRect br(1, 1, width()-2, height()-2);
-		int dx = (br.width() - pixmap.width()) / 2;
-		int dy = (br.height() - pixmap.height()) / 2;
-		p->drawPixmap(br.x() + dx, br.y() + dy, pixmap);
-	}
+    setPixmap(iconSet.pixmap(QIconSet::Automatic, QIconSet::Normal, QIconSet::On));
 }
+
