@@ -29,8 +29,7 @@
 #include <kaboutdata.h>
 #include <kaboutapplication.h>
 
-// used for the applet itself
-#include <qpushbutton.h>
+#include <qpalette.h>
 
 // used everywhere :)
 #include <qstring.h>
@@ -38,10 +37,11 @@
 #include "playerInterface.h"
 #include "configfrontend.h"
 #include "mediacontroliface.h"
+#include "simplebutton.h"
 
 #define MEDIACONTROL_VERSION "0.4"
 
-class QSlider;
+class MCSlider;
 class KPopupMenu;
 class KInstance;
 class MediaControlConfig;
@@ -50,16 +50,14 @@ class MediaControlToolTip;
 
 // =============================================================================
 
-class TrayButton : public QPushButton
+class TrayButton : public SimpleButton
 {
 	Q_OBJECT
 
 	public:
 		TrayButton(QWidget* parent, const char* name);
 		virtual ~TrayButton() {}
-
-	protected:
-		void drawButton(QPainter *p);
+		void setIconSet(const QIconSet &iconSet);
 };
 
 // =============================================================================
@@ -94,12 +92,14 @@ class MediaControl : public KPanelApplet, virtual public MediaControlIface
 		TrayButton *playpause_button;  // Start/Pause playing
 		TrayButton *stop_button;  // Stop the music
 		TrayButton *next_button;  // GoTo Next Playlist-Item
-		QSlider *time_slider;
+		MCSlider *time_slider;
 		int mLastLen, mLastTime, mLastStatus;
 		KPopupMenu *rmbMenu;
 
 		virtual void mousePressEvent(QMouseEvent* e);
-		void resizeEvent(QResizeEvent*);
+		virtual void moveEvent(QMoveEvent*);
+		virtual void paletteChange(const QPalette&);
+		virtual void resizeEvent(QResizeEvent*);
 		virtual bool eventFilter(QObject *watched, QEvent *e);
 
 		friend class MediaControlToolTip;
