@@ -83,19 +83,20 @@ QString PluginBase::fixRelativeURL(const QString &s, const KURL &baseurl)
         }
         else if (s2.startsWith("/"))
         {
-            u=baseurl;
-            u.setPath(s2);
+            KURL b2(baseurl);
+            b2.setPath(QString()); // delete path and query, so that only protocol://host remains
+            b2.setQuery(QString());
+            u = KURL(b2, s2.remove(0,1)); // remove leading "/" 
         }
         else
         {
-            u=baseurl;
-            u.addPath(s2);
+            u = KURL(baseurl, s2);
         }
-        u.cleanPath();
     }
     else
         u=s2;
 
     u.cleanPath();
+    //kdDebug() << "AKREGATOR_PLUGIN_FIXURL: " << "url=" << s << " baseurl=" << baseurl.url() << " fixed=" << u.url() << endl;
     return u.url();
 }
