@@ -70,7 +70,7 @@ void KCMKuick::load()
     config.setGroup("kuick-copy");
     dialog->m_sbCopy->setValue(config.readNumEntry("ShowRecent",5) );
 
-    config.setGroup("kuick-write" );
+    config.setGroup("kuick-move" );
     dialog->m_sbMove->setValue(config.readNumEntry("ShowRecent",5) );
     
     KConfig cfg("kuick_plugin.desktop", true, false, "services");
@@ -102,7 +102,7 @@ void KCMKuick::save()
 
     config.writeEntry("ShowRecent", dialog->m_sbCopy->value() );
 
-    config.setGroup("kuick-write" );
+    config.setGroup("kuick-move" );
     config.writeEntry("ShowRecent", dialog->m_sbMove->value() );
 
     config.sync();		//is it necessary ?
@@ -130,7 +130,7 @@ void KCMKuick::slotClearCopyCache( ) {
 
 void KCMKuick::slotClearMoveCache() {
     KConfig config("konquerorrc");
-    config.setGroup("kuick-write" );
+    config.setGroup("kuick-move" );
     config.writePathEntry("Paths", QStringList() );
     config.sync();		//is it necessary ?
 }
