@@ -84,14 +84,9 @@ public:
 
 	/**
 	 * Change the file to have open
+	 * @return true if file is playable, false otherwise
 	 */
-	void openFile(const KURL &f);
-
-	/**
-	 * Get a shell glob string for use with a KFileDialog, displaying the
-	 * file types aRts claims to have PlayObjects for.
-	 */
-	QString shellGlob()const;
+	bool openFile(const KURL &f);
 
 public slots:
 	/**
@@ -132,17 +127,22 @@ signals:
 	void timeout();
 
 	/**
-	 * State changed to stop
+	 * State is to Empty
+	 */
+	void empty();
+
+	/**
+	 * State is to Stopped
 	 */
 	void stopped();
 
 	/**
-	 * State changed to playing
+	 * State is to Playing
 	 */
 	void playing();
 
 	/**
-	 * State changed to paused
+	 * State is to Paused
 	 */
 	void paused();
 
