@@ -395,12 +395,15 @@ void ArchiveDialog::saveArchiveRecursive(const DOM::Node &pNode, const KURL& bas
 QString ArchiveDialog::handleLink(const KURL& _url, const QString& _link)
 {
    KURL url(getAbsoluteURL(_url, _link));
-   QString tarFileName;
 
-   if (m_state==Retrieving)
-      m_urlsToDownload.append(url);
-   else if (m_state==Saving)
-      tarFileName = m_downloadedURLDict[url.url()];
+   QString tarFileName;
+   if (kapp->authorizeURLAction("redirect", _url, url))
+   {
+       if (m_state==Retrieving)
+           m_urlsToDownload.append(url);
+       else if (m_state==Saving)
+           tarFileName = m_downloadedURLDict[url.url()];
+   }
 
    return tarFileName;
 }
