@@ -17,7 +17,7 @@
    Boston, MA 02110-1301, USA.
 */
 
-// $Id: webarchivecreator.cpp 465369 2005-09-29 14:33:08Z mueller $
+// $Id: webarchivecreator.cpp 626814 2007-01-24 17:16:52Z mueller $
 
 #include <time.h>
 
@@ -32,7 +32,7 @@
 
 extern "C"
 {
-	ThumbCreator *new_creator()
+	ThumbCreator * KDE_EXPORT new_creator()
 	{
 		return new WebArchiveCreator;
 	}
