@@ -69,9 +69,8 @@ void Bitmap<Type>::fadeStar()
 	do
 	{
 		if (*ptr)
-			*(ptr++) -= ((*ptr & 0xf0f0f0f0ul) >> 4) + ((*ptr & 0xe0e0e0e0ul) >> 5);
-		else 
-			ptr++;
+			*ptr -= ((*ptr & 0xf0f0f0f0ul) >> 4) + ((*ptr & 0xe0e0e0e0ul) >> 5);
+		ptr++;
 	} while(--i > 0);
 }
 
