@@ -5,23 +5,24 @@
 #include <noatun/player.h>
 #include <noatun/app.h>
 #include <kmainwindow.h>
+#include <qvaluevector.h>
 #include <khtml_part.h>
 #include <kaction.h>
-#include <qvaluestack.h>
+#include "cmodule.h"
 
 class HistoryManager;
 
 class Lyrics : public KMainWindow, public Plugin {
 Q_OBJECT
-NOATUNPLUGIND;
 
 public:
   Lyrics();
   ~Lyrics();
   void go(const KURL &);
+  void setProviders( QValueVector<SearchProvider> &sites );
 
 public slots:
-  void viewLyrics();
+  void viewLyrics(int index = -1);
   void back();
   void forward();
 
@@ -33,36 +34,22 @@ protected slots:
   void openURLRequest( const KURL &, const KParts::URLArgs & );
   void loadingURL(KIO::Job *);
   void loadedURL();
+  void attach(bool);
   void newSong();
+  void goTo();
 
 private:
 	int menuID;
   KAction *back_act, *forward_act;
   KToggleAction *follow_act;
+  KToggleAction *attach_act;
+  KSelectAction *site_act;
 	KHTMLPart *htmlpart;
+  QValueVector<SearchProvider> mSites;
   HistoryManager *history;
+  bool active;
 
 };
 
-class HistoryManager : public QObject {
-  Q_OBJECT
-  public:
-    HistoryManager();
-    ~HistoryManager();
-    KURL back();
-    KURL forward();
-    void addURL(const KURL &);
-    enum Buttons {
-      Back,
-      Forward
-    };
-  signals:
-    void uiChanged(int, bool);
-  protected:
-    QValueStack<KURL> back_stack;
-    QValueStack<KURL> forward_stack;
-    KURL currentURL;
-};
-  
 
 #endif
