@@ -11,6 +11,7 @@
 #include <iostream>
 
 #include <klocale.h>
+#include <string.h>
 
 #include <noatun/player.h>
 
@@ -55,7 +56,7 @@ static void treeItemMerge(
 	while (fromfirst <= fromlast)
 		*tempat++ = *fromfirst++;
 		
-	std::memcpy(set, temp, items*sizeof(TreeItem**));
+	::memcpy(set, temp, items*sizeof(TreeItem**));
 	delete [] temp;
 }
 
