@@ -11,22 +11,31 @@
 #include "syna.h"
 #include <kprocess.h>
 
+class SynaePrefs;
+class KProcess;
+
 class SynaeScope : public QObject, public Plugin
 {
 Q_OBJECT
-	
+
 public:
 	SynaeScope();
 	virtual ~SynaeScope();
 
 	void init();
+	void runScope();
 
 private slots:
 	void processExited(KProcess *);
+	void readConfig();
+	void receivedStdout(KProcess *, char *buf, int len);
+	void receivedStderr(KProcess *, char *buf, int len);
 
 private:
 	KProcess process;
+	QString scopeExePath;
+	bool restarting;
+	SynaePrefs *mPrefs;
 };
 
-
-#endif 
+#endif
