@@ -13,7 +13,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <kinstance.h>
 
@@ -42,7 +42,8 @@ typedef struct t_config {
     int teff,tcol;
 } t_config;
 
-t_config config = {320, 240, 1, 50, 50};
+t_config config = {512, 352, 1, 100, 100};
+//t_config config = {640, 480, 1, 100, 100};
 
 bool finished;
 SDL_Thread *thread;
@@ -76,11 +77,11 @@ int main(int, char **)
 	printf("%u\n", winID());
 	fflush(stdout);
 	init_renderer2();
-	thread = SDL_CreateThread((int (*)(void *))renderer, 0);
+	thread = SDL_CreateThread((int (*)(void *))renderer, NULL);
 
 	fd_set set;
 	struct timeval tv;
-	while(1)
+	while(check_finished() != 1)
 	{
 		FD_ZERO(&set);
 		FD_SET(STDIN_FILENO, &set);
@@ -92,5 +93,8 @@ int main(int, char **)
 			read(STDIN_FILENO, (void *)pcm_data, sizeof(short) * 2 * 512);
 			SDL_mutexV(access_mutex);
 		}
+		usleep(5);
 	}
+	/*fprintf(stderr,"exiting main()\n");*/
+	SDL_WaitThread(thread, NULL);
 }
