@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef imagevisualizer_h
@@ -24,12 +24,19 @@
 
 class QPixmap;
 class QLabel;
-class ImageVisualizer : public QVBox{
- public:
+class ImageVisualizer : public QVBox
+{
+  Q_OBJECT
+public:
   ImageVisualizer(QWidget *parent, const char *name, const QString &fileName );
-  ~ImageVisualizer();
- private:
-  QPixmap *pixmap;
+
+private:
+  void loadImage( const QString& path );
+
+private slots:
+  void downloadImage( const QString& url );
+
+private:
   QLabel *pic;
   QLabel *description;
 };
